@@ -8,6 +8,7 @@ describe 'ceilometer with mysql' do
       pp= <<-EOS
       include openstack_integration
       include openstack_integration::repos
+      include openstack_integration::apache
       include openstack_integration::rabbitmq
       include openstack_integration::mysql
       include openstack_integration::keystone
@@ -22,9 +23,5 @@ describe 'ceilometer with mysql' do
       apply_manifest(pp, :catch_changes => true)
     end
 
-    describe cron do
-      it { is_expected.to have_entry('1 0 * * * ceilometer-expirer').with_user('ceilometer') }
-    end
-
   end
 end
